@@ -5,8 +5,10 @@ TODO: add a docstring.
 
 # We keep all initialization code in a separate module.
 
-from pystache.init import parse, render, Renderer, TemplateSpec
+from pystache.init import Renderer, TemplateSpec, parse, render
+
+from ._version import __version__
+
+version = __version__
 
 __all__ = ['parse', 'render', 'Renderer', 'TemplateSpec']
-
-__version__ = '0.6.0'
